@@ -194,7 +194,7 @@ def get_plans():
 console = Console()
 while 1:
     try:
-        cmd = input('span % ').split()
+        cmd = input('span # ').split()
         readline.write_history_file(files['history'])
         if cmd == []:
             continue
